==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Edit/Paste/ts/Paste_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>Paste</name>
    <message>
        <location filename="../Paste.js" line="+77"/>
        <source>Position</source>
        <translation>Sijainti</translation>
    </message>
    <message>
        <location filename="../Paste.ui" line="+17"/>
        <source>Rotation:</source>
        <translation>Kiertäminen:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Rotate pasted entities&lt;br&gt;by this angle</source>
        <translation>Kierrä liitetyt kohteet&lt;br&gt;tämän kulman mukaan</translation>
    </message>
    <message>
        <location line="+97"/>
        <source>Scale:</source>
        <translation>Mittakaava:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Scale pasted entities&lt;br&gt;by this factor</source>
        <translation>Mittakaavaan liitetyt kohteet&lt;br&gt;tämän tekijän mukaan</translation>
    </message>
    <message>
        <location line="+72"/>
        <source>Flip pasted entities&lt;br&gt;horizontally</source>
        <translation>Käännä liitetyt kohteet&lt;br&gt;vaakasuoraan</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Flip pasted entities&lt;br&gt;vertically</source>
        <translation>Käännä liitetyt kohteet&lt;br&gt;pystysuoraan</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Paste all entities&lt;br&gt;to current layer&lt;br&gt;instead of original layer</source>
        <translation>Liitä kaikki kohteet&lt;br&gt;nykyiseen tasoon&lt;br&gt;alkuperäisen tason sijasta</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>To current layer</source>
        <translation>Nykyiseen tasoon</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Overwrite existing layers&lt;br&gt;in drawing with&lt;br&gt;layers from clipboard</source>
        <translation>Korvaa/ylikirjoita olemassa olevat tasot&lt;br&gt;nykyisessä piirroksessa&lt;br&gt;leikepöydän tasoilla</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Overwrite layers</source>
        <translation>Korvaa/ylikirjoita tasot</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Overwrite existing blocks&lt;br&gt;in drawing with&lt;br&gt;blocks from clipboard</source>
        <translation>Korvaa/ylikirjoita olemassa olevat lohkot&lt;br&gt;nykyisessä piirroksessa&lt;br&gt;leikepöydän lohkoilla</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Overwrite blocks</source>
        <translation>Korvaa/ylikirjoita lohkot</translation>
    </message>
    <message>
        <location filename="../PasteInit.js" line="+2"/>
        <source>&amp;Paste</source>
        <translation>&amp;Liitä</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Edit/Paste/ts/Paste_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>Paste</name>
    <message>
        <location filename="../Paste.js" line="+52"/>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Paste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Position</source>
        <translation>Sijainti</translation>
    </message>
    <message>
        <location filename="../Paste.ui" line="+17"/>
        <source>Rotation:</source>
        <translation>Kiertäminen:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Rotate pasted entities&lt;br&gt;by this angle</source>
        <translation>Kierrä liitetyt kohteet&lt;br&gt;tämän kulman mukaan</translation>
    </message>
    <message>
        <location line="+107"/>
        <source>Scale:</source>
        <translation>Mittakaava:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Scale pasted entities&lt;br&gt;by this factor</source>
        <translation>Mittakaavaan liitetyt kohteet&lt;br&gt;tämän tekijän mukaan</translation>
    </message>
    <message>
        <location line="+72"/>
        <source>Flip pasted entities&lt;br&gt;horizontally</source>
        <translation>Käännä liitetyt kohteet&lt;br&gt;vaakasuoraan</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Flip pasted entities&lt;br&gt;vertically</source>
        <translation>Käännä liitetyt kohteet&lt;br&gt;pystysuoraan</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Paste all entities&lt;br&gt;to current layer&lt;br&gt;instead of original layer</source>
        <translation>Liitä kaikki kohteet&lt;br&gt;nykyiseen tasoon&lt;br&gt;alkuperäisen tason sijasta</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>To current layer</source>
        <translation>Nykyiseen tasoon</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Overwrite existing layers&lt;br&gt;in drawing with&lt;br&gt;layers from clipboard</source>
        <translation>Korvaa/ylikirjoita olemassa olevat tasot&lt;br&gt;nykyisessä piirroksessa&lt;br&gt;leikepöydän tasoilla</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Overwrite layers</source>
        <translation>Korvaa/ylikirjoita tasot</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Overwrite existing blocks&lt;br&gt;in drawing with&lt;br&gt;blocks from clipboard</source>
        <translation>Korvaa/ylikirjoita olemassa olevat lohkot&lt;br&gt;nykyisessä piirroksessa&lt;br&gt;leikepöydän lohkoilla</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Overwrite blocks</source>
        <translation>Korvaa/ylikirjoita lohkot</translation>
    </message>
    <message>
        <location filename="../PasteInit.js" line="+2"/>
        <source>&amp;Paste</source>
        <translation>&amp;Liitä</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Reset to defaults every time tool is used</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
